@@ -15,10 +15,81 @@ import tornado.websocket
 import aiohttp
 from traitlets.config import LoggingConfigurable
 import mimetypes
+import requests
+from google.oauth2 import id_token
+from google.auth.transport import requests as google_requests
 
 # Default proxy port
 DEFAULT_PROXY_PORT = 3000
 
+
+class OAuthCallbackHandler(JupyterHandler):
+    """
+    Handler for /static/oauth-callback.html endpoint.
+    Serves the OAuth callback HTML file for Google authentication.
+    """
+    
+    async def get(self):
+        """Handle GET requests to serve the OAuth callback HTML"""
+        try:
+            # Get the path to the static directory
+            import os
+            import pkg_resources
+            
+            # Try to get the file from the installed package first
+            try:
+                # This works when the package is installed via pip
+                # The static files are installed in the labextension directory
+                callback_content = pkg_resources.resource_string('escobar', 'labextension/static/oauth-callback.html').decode('utf-8')
+                
+                self.log.info(f"🔐 CALLBACK: Serving OAuth callback from installed package")
+                
+                # Set proper headers
+                self.set_header('Content-Type', 'text/html; charset=UTF-8')
+                self.set_header('Cache-Control', 'no-cache, no-store, must-revalidate')
+                self.set_header('Pragma', 'no-cache')
+                self.set_header('Expires', '0')
+                
+                # Write the HTML content
+                self.write(callback_content)
+                self.log.info(f"🔐 CALLBACK: Successfully served OAuth callback HTML from package")
+                return
+                
+            except (ImportError, FileNotFoundError, OSError):
+                # Fallback to file system path for development
+                current_dir = os.path.dirname(os.path.abspath(__file__))
+                project_root = os.path.dirname(current_dir)
+                callback_file_path = os.path.join(project_root, 'static', 'oauth-callback.html')
+            
+            self.log.info(f"🔐 CALLBACK: Serving OAuth callback from: {callback_file_path}")
+            
+            # Check if file exists
+            if not os.path.exists(callback_file_path):
+                self.log.error(f"🔐 CALLBACK: OAuth callback file not found: {callback_file_path}")
+                self.set_status(404)
+                self.finish("OAuth callback file not found")
+                return
+            
+            # Read and serve the HTML file
+            with open(callback_file_path, 'r', encoding='utf-8') as f:
+                html_content = f.read()
+            
+            # Set proper headers
+            self.set_header('Content-Type', 'text/html; charset=UTF-8')
+            self.set_header('Cache-Control', 'no-cache, no-store, must-revalidate')
+            self.set_header('Pragma', 'no-cache')
+            self.set_header('Expires', '0')
+            
+            # Write the HTML content
+            self.write(html_content)
+            self.log.info(f"🔐 CALLBACK: Successfully served OAuth callback HTML")
+            
+        except Exception as e:
+            self.log.error(f"🔐 CALLBACK: Error serving OAuth callback: {e}")
+            self.set_status(500)
+            self.finish(f"Error serving OAuth callback: {str(e)}")
+
+
 class ProxyHandler(JupyterHandler):
     """
     Handler for /proxy endpoint.
@@ -184,16 +255,11 @@ class WebSocketProxyHandler(tornado.websocket.WebSocketHandler):
         # Determine if we're in Docker
         is_docker = dockerenv_exists or docker_env or cgroup_docker
         
-        print(f"[ESCOBAR-WS] Docker detection indicators: {docker_indicators}")
-        print(f"[ESCOBAR-WS] Final Docker detection result: {is_docker}")
-        
         if not is_docker:
-            print(f"[ESCOBAR-WS] Not in Docker container, using original URL: {url}")
             return url
         
         # Parse the URL to extract components
         parsed = urlparse(url)
-        print(f"[ESCOBAR-WS] Parsed URL - hostname: '{parsed.hostname}', netloc: '{parsed.netloc}'")
         
         # Check if hostname is localhost or 127.0.0.1
         if parsed.hostname in ['localhost', '127.0.0.1']:
@@ -202,10 +268,7 @@ class WebSocketProxyHandler(tornado.websocket.WebSocketHandler):
             new_parsed = parsed._replace(netloc=new_netloc)
             new_url = urlunparse(new_parsed)
             
-            print(f"[ESCOBAR-WS] Docker hostname resolution: {url} → {new_url}")
             return new_url
-        else:
-            print(f"[ESCOBAR-WS] Docker container detected, but hostname '{parsed.hostname}' is not localhost/127.0.0.1, keeping original: {url}")
         
         return url
     
@@ -238,30 +301,22 @@ class WebSocketProxyHandler(tornado.websocket.WebSocketHandler):
         Get user-configured Bonnie URL from bonnie_url query parameter.
         This allows the frontend to override the environment variable.
         """
-        print(f"[ESCOBAR-WS] === READING USER BONNIE URL FROM QUERY PARAMETER ===")
-        
         try:
             # Get the bonnieUrl from query parameters
             bonnie_url = self.get_argument('bonnie_url', None)
-            print(f"[ESCOBAR-WS] bonnie_url query parameter value: '{bonnie_url}'")
             
             if bonnie_url and bonnie_url.strip():
                 # Validate that it's a WebSocket URL
                 if bonnie_url.startswith(('ws://', 'wss://')):
-                    print(f"[ESCOBAR-WS] Valid user Bonnie URL from query parameter: {bonnie_url}")
                     return bonnie_url.strip()
                 else:
-                    print(f"[ESCOBAR-WS] Invalid Bonnie URL format (must start with ws:// or wss://): {bonnie_url}")
                     return None
             else:
-                print(f"[ESCOBAR-WS] No bonnie_url query parameter provided")
                 return None
                 
         except Exception as e:
             print(f"[ESCOBAR-WS] Error reading bonnie_url query parameter: {e}")
             return None
-        finally:
-            print(f"[ESCOBAR-WS] === END BONNIE URL QUERY PARAMETER READ ===")
     
     def _get_target_url(self):
         """
@@ -375,19 +430,10 @@ class WebSocketProxyHandler(tornado.websocket.WebSocketHandler):
     
     async def on_message(self, message):
         """Called when a message is received from the client"""
-        print(f"[ESCOBAR-WS] === CLIENT MESSAGE RECEIVED ===")
-        print(f"[ESCOBAR-WS] Message length: {len(message)}")
-        print(f"[ESCOBAR-WS] Message type: {type(message)}")
-        print(f"[ESCOBAR-WS] Message preview: {message[:500]}...")
-        print(f"[ESCOBAR-WS] Target WS exists: {self.target_ws is not None}")
-        print(f"[ESCOBAR-WS] Is closing: {self.is_closing}")
-        
         if self.target_ws and not self.is_closing:
             try:
-                print(f"[ESCOBAR-WS] Forwarding message to target server")
                 # Forward message to target server
                 await self.target_ws.send(message)
-                print(f"[ESCOBAR-WS] Message successfully forwarded to target")
                 logging.debug(f"Forwarded message to target: {message[:100]}...")
             except Exception as e:
                 print(f"[ESCOBAR-WS] ERROR forwarding message to target:")
@@ -395,60 +441,27 @@ class WebSocketProxyHandler(tornado.websocket.WebSocketHandler):
                 print(f"[ESCOBAR-WS]   Error type: {type(e).__name__}")
                 logging.error(f"Error forwarding message to target: {str(e)}")
                 self.close(code=1011, reason="Target connection error")
-        else:
-            print(f"[ESCOBAR-WS] Cannot forward message - target_ws: {self.target_ws}, is_closing: {self.is_closing}")
-        print(f"[ESCOBAR-WS] === END CLIENT MESSAGE ===")
     
     async def _forward_from_target(self):
         """Forward messages from target server to client"""
-        print(f"[ESCOBAR-WS] === STARTING TARGET MESSAGE FORWARDING ===")
-        print(f"[ESCOBAR-WS] Target WS state: {self.target_ws.state if self.target_ws else 'None'}")
-        
         try:
-            message_count = 0
             async for message in self.target_ws:
-                message_count += 1
-                print(f"[ESCOBAR-WS] === TARGET MESSAGE #{message_count} ===")
-                print(f"[ESCOBAR-WS] Message length: {len(message)}")
-                print(f"[ESCOBAR-WS] Message type: {type(message)}")
-                print(f"[ESCOBAR-WS] Message preview: {message[:500]}...")
-                print(f"[ESCOBAR-WS] Is closing: {self.is_closing}")
-                
                 if not self.is_closing:
-                    print(f"[ESCOBAR-WS] Forwarding message to client")
                     # Forward message to client
                     self.write_message(message)
-                    print(f"[ESCOBAR-WS] Message successfully forwarded to client")
                     logging.debug(f"Forwarded message from target: {message[:100]}...")
                 else:
-                    print(f"[ESCOBAR-WS] Breaking forwarding loop - connection is closing")
                     break
-                print(f"[ESCOBAR-WS] === END TARGET MESSAGE #{message_count} ===")
                 
         except websockets.exceptions.ConnectionClosed as e:
-            print(f"[ESCOBAR-WS] === TARGET CONNECTION CLOSED DETAILS ===")
-            print(f"[ESCOBAR-WS] Target websocket connection closed")
-            print(f"[ESCOBAR-WS] Close code: {getattr(e, 'code', 'NO_CODE')}")
-            print(f"[ESCOBAR-WS] Close reason: {getattr(e, 'reason', 'NO_REASON')}")
-            print(f"[ESCOBAR-WS] Exception type: {type(e).__name__}")
-            print(f"[ESCOBAR-WS] Exception str: {str(e)}")
-            print(f"[ESCOBAR-WS] Target WS final state: {getattr(self.target_ws, 'state', 'NO_STATE') if self.target_ws else 'NO_TARGET_WS'}")
-            print(f"[ESCOBAR-WS] Messages processed before disconnect: {message_count}")
-            print(f"[ESCOBAR-WS] === END TARGET CONNECTION CLOSED DETAILS ===")
-            
             logging.info(f"Target websocket connection closed - code: {getattr(e, 'code', 'NO_CODE')}, reason: {getattr(e, 'reason', 'NO_REASON')}")
             
             if not self.is_closing:
-                print(f"[ESCOBAR-WS] Closing client connection due to target disconnect")
                 self.close(code=1011, reason="Target server disconnected")
         except Exception as e:
             print(f"[ESCOBAR-WS] === TARGET MESSAGE FORWARDING ERROR ===")
             print(f"[ESCOBAR-WS] Error: {str(e)}")
             print(f"[ESCOBAR-WS] Error type: {type(e).__name__}")
-            print(f"[ESCOBAR-WS] Messages processed before error: {message_count}")
-            print(f"[ESCOBAR-WS] Target WS state: {getattr(self.target_ws, 'state', 'NO_STATE') if self.target_ws else 'NO_TARGET_WS'}")
-            if hasattr(e, '__dict__'):
-                print(f"[ESCOBAR-WS] Error attributes: {e.__dict__}")
             if hasattr(e, 'errno'):
                 print(f"[ESCOBAR-WS] Errno: {e.errno}")
             if hasattr(e, 'strerror'):
@@ -457,66 +470,37 @@ class WebSocketProxyHandler(tornado.websocket.WebSocketHandler):
             
             logging.error(f"Error receiving from target websocket: {str(e)}")
             if not self.is_closing:
-                print(f"[ESCOBAR-WS] Closing client connection due to target error")
                 self.close(code=1011, reason="Target connection error")
-        
-        print(f"[ESCOBAR-WS] === TARGET MESSAGE FORWARDING ENDED ===")
     
     def on_close(self):
         """Called when websocket connection is closed"""
-        print(f"[ESCOBAR-WS] === CLIENT CONNECTION CLOSED ===")
-        print(f"[ESCOBAR-WS] Setting is_closing flag to True")
         self.is_closing = True
-        print(f"[ESCOBAR-WS] Target WS exists: {self.target_ws is not None}")
         
         logging.info("WebSocket connection closed")
         
         # Close target connection if it exists
         if self.target_ws:
-            print(f"[ESCOBAR-WS] Scheduling target connection cleanup")
             asyncio.create_task(self._close_target_connection())
-        else:
-            print(f"[ESCOBAR-WS] No target connection to clean up")
-        
-        print(f"[ESCOBAR-WS] === END CLIENT CONNECTION CLOSED ===")
     
     async def _close_target_connection(self):
         """Safely close the target websocket connection"""
-        print(f"[ESCOBAR-WS] === CLOSING TARGET CONNECTION ===")
         try:
             if self.target_ws:
-                print(f"[ESCOBAR-WS] Target WS exists, checking state")
-                print(f"[ESCOBAR-WS] Target WS type: {type(self.target_ws)}")
-                print(f"[ESCOBAR-WS] Target WS state: {getattr(self.target_ws, 'state', 'NO_STATE_ATTR')}")
-                
                 # Check if connection is already closed using the correct websockets library API
                 try:
                     is_closed = self.target_ws.state.name == 'CLOSED'
-                    print(f"[ESCOBAR-WS] Target WS is closed: {is_closed}")
                 except AttributeError:
                     # Fallback: just try to close it regardless of state
-                    print(f"[ESCOBAR-WS] Cannot check state, will attempt to close anyway")
                     is_closed = False
                 
                 if not is_closed:
-                    print(f"[ESCOBAR-WS] Target WS is open, closing it")
                     await self.target_ws.close()
-                    print(f"[ESCOBAR-WS] Target connection closed successfully")
                     logging.info("Target websocket connection closed")
-                else:
-                    print(f"[ESCOBAR-WS] Target WS already closed")
-            else:
-                print(f"[ESCOBAR-WS] No target WS to close")
         except Exception as e:
             print(f"[ESCOBAR-WS] ERROR closing target connection:")
             print(f"[ESCOBAR-WS]   Error: {str(e)}")
             print(f"[ESCOBAR-WS]   Error type: {type(e).__name__}")
-            print(f"[ESCOBAR-WS]   Target WS type: {type(self.target_ws) if self.target_ws else 'None'}")
-            if hasattr(e, '__dict__'):
-                print(f"[ESCOBAR-WS]   Error attributes: {e.__dict__}")
             logging.error(f"Error closing target websocket: {str(e)}")
-        
-        print(f"[ESCOBAR-WS] === END CLOSING TARGET CONNECTION ===")
 
 
 def setup_handlers(web_app):
@@ -584,9 +568,14 @@ def setup_handlers(web_app):
     for pattern in ws_patterns:
         print(f"[ESCOBAR-WS]   - {pattern}")
     
+    # Register the OAuth callback endpoint - use escobar-specific path to avoid conflicts
+    oauth_callback_pattern = url_path_join(base_url, "escobar", "oauth-callback.html")
+    print(f"[ESCOBAR-WS] OAuth callback pattern: {oauth_callback_pattern}")
+    
     # Build handlers list with all WebSocket patterns
     handlers = [
         (proxy_pattern, ProxyHandler),
+        (oauth_callback_pattern, OAuthCallbackHandler),
         *[(pattern, WebSocketProxyHandler) for pattern in ws_patterns]
     ]
     
