@@ -9,6 +9,7 @@ export interface ILocalSettings {
     username: string;
     usernameFromJupyterHub: boolean;
     bonnieUrl?: string;
+    googleClientId?: string;
 }
 
 /**
@@ -38,7 +39,8 @@ const DEFAULT_LOCAL_SETTINGS: ILocalSettings = {
     serverUrl: process.env.SERVER_URL || '/ws',
     username: 'User',
     usernameFromJupyterHub: false,
-    bonnieUrl: 'ws://bonnie:8777/ws'
+    bonnieUrl: 'ws://bonnie:8777/ws',
+    googleClientId: ''
 };
 
 /**
@@ -105,7 +107,8 @@ export class SettingsManager {
                 serverUrl: composite.serverUrl || DEFAULT_LOCAL_SETTINGS.serverUrl,
                 username: composite.username || DEFAULT_LOCAL_SETTINGS.username,
                 usernameFromJupyterHub: composite.usernameFromJupyterHub || DEFAULT_LOCAL_SETTINGS.usernameFromJupyterHub,
-                bonnieUrl: composite.bonnieUrl || DEFAULT_LOCAL_SETTINGS.bonnieUrl
+                bonnieUrl: composite.bonnieUrl || DEFAULT_LOCAL_SETTINGS.bonnieUrl,
+                googleClientId: composite.googleClientId || DEFAULT_LOCAL_SETTINGS.googleClientId
             };
 
             // Always prioritize environment variable for serverUrl
@@ -140,7 +143,8 @@ export class SettingsManager {
                 serverUrl: settings.serverUrl,
                 username: settings.username,
                 usernameFromJupyterHub: settings.usernameFromJupyterHub,
-                bonnieUrl: settings.bonnieUrl
+                bonnieUrl: settings.bonnieUrl,
+                googleClientId: settings.googleClientId
             });
 
             await settingsPlugin.set('serverUrl', settings.serverUrl);
@@ -149,6 +153,9 @@ export class SettingsManager {
             if (settings.bonnieUrl !== undefined) {
                 await settingsPlugin.set('bonnieUrl', settings.bonnieUrl);
             }
+            if (settings.googleClientId !== undefined) {
+                await settingsPlugin.set('googleClientId', settings.googleClientId);
+            }
 
             this.localSettings = { ...settings };
             console.log('🔧 SETTINGS: Local settings saved successfully');
